@@ -20,8 +20,8 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
     def delete_event(self, event_id):
         """Delete a event
 
-            Arguments:
-                event_id (str): The database key for the event
+        Arguments:
+            event_id (str): The database key for the event
         """
         LOG.info("Deleting event{0}".format(event_id))
         if not isinstance(event_id, ObjectId):
@@ -94,16 +94,16 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
     ):
         """Fetch events from the database.
 
-          Args:
-            institute (dict): An institute
-            case (dict): A case
-            variant_id (str, optional): global variant id
-            level (str, optional): restrict comments to 'specific' or 'global'
-            comments (bool, optional): restrict events to include only comments
-            panel (str): A panel name
+        Args:
+          institute (dict): An institute
+          case (dict): A case
+          variant_id (str, optional): global variant id
+          level (str, optional): restrict comments to 'specific' or 'global'
+          comments (bool, optional): restrict events to include only comments
+          panel (str): A panel name
 
-          Returns:
-              pymongo.Cursor: Query result
+        Returns:
+            pymongo.Cursor: Query result
         """
 
         query = {}
@@ -165,16 +165,16 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
     ):
         """Add a new phenotype term to a case
 
-            Create a phenotype term and event with the given information
+        Create a phenotype term and event with the given information
 
-            Args:
-                institute (Institute): A Institute object
-                case (Case): Case object
-                user (User): A User object
-                link (str): The url to be used in the event
-                hpo_term (str): A hpo id
-                omim_term (str): A omim id
-                is_group (bool): is phenotype term a group?
+        Args:
+            institute (Institute): A Institute object
+            case (Case): Case object
+            user (User): A User object
+            link (str): The url to be used in the event
+            hpo_term (str): A hpo id
+            omim_term (str): A omim id
+            is_group (bool): is phenotype term a group?
 
         """
         hpo_results = []
@@ -193,9 +193,7 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
             ## TODO Should ve raise a more proper exception here?
             raise e
 
-        existing_terms = set(
-            term["phenotype_id"] for term in case.get("phenotype_terms", [])
-        )
+        existing_terms = set(term["phenotype_id"] for term in case.get("phenotype_terms", []))
 
         updated_case = case
         phenotype_terms = []
@@ -248,9 +246,7 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
         LOG.debug("Case updated")
         return updated_case
 
-    def remove_phenotype(
-        self, institute, case, user, link, phenotype_id, is_group=False
-    ):
+    def remove_phenotype(self, institute, case, user, link, phenotype_id, is_group=False):
         """Remove an existing phenotype from a case
 
         Args:
@@ -334,9 +330,7 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
             comment(dict): The comment event that was inserted
         """
         if comment_level not in COMMENT_LEVELS:
-            raise SyntaxError(
-                "Comment levels can only be in {}".format(",".join(COMMENT_LEVELS))
-            )
+            raise SyntaxError("Comment levels can only be in {}".format(",".join(COMMENT_LEVELS)))
 
         if variant:
             LOG.info(
@@ -359,9 +353,7 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
             )
 
         else:
-            LOG.info(
-                "Creating event for a comment on case {0}".format(case["display_name"])
-            )
+            LOG.info("Creating event for a comment on case {0}".format(case["display_name"]))
 
             comment = self.create_event(
                 institute=institute,
@@ -392,9 +384,7 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
         if new_var["_id"] == old_var["_id"]:
             return new_comments
 
-        link = "/{0}/{1}/{2}".format(
-            new_var["institute"], case_obj["display_name"], new_var["_id"]
-        )
+        link = "/{0}/{1}/{2}".format(new_var["institute"], case_obj["display_name"], new_var["_id"])
 
         # collect all comments for the old variant
         comments_query = self.events(
