@@ -124,7 +124,7 @@ def parse_variant(
     ################# Position specific #################
     parsed_variant["chromosome"] = chrom
 
-    coordinates = parse_coordinates(variant, category)
+    coordinates = parse_coordinates(variant, category, case.get("genome_build"))
 
     parsed_variant["position"] = coordinates["position"]
     parsed_variant["sub_category"] = coordinates["sub_category"]
@@ -236,9 +236,7 @@ def parse_variant(
     parsed_transcripts = []
     dbsnp_ids = set()
     cosmic_ids = set()
-    for parsed_transcript in parse_transcripts(
-        raw_transcripts, parsed_variant["alternative"]
-    ):
+    for parsed_transcript in parse_transcripts(raw_transcripts, parsed_variant["alternative"]):
         parsed_transcripts.append(parsed_transcript)
         for dbsnp in parsed_transcript.get("dbsnp", []):
             dbsnp_ids.add(dbsnp)
