@@ -1,6 +1,6 @@
 """Code for flask app"""
 import logging
-
+import re
 import coloredlogs
 from flask import Flask, current_app, redirect, request, url_for
 from flask_babel import Babel
@@ -74,12 +74,8 @@ def create_app(config_file=None, config=None):
     def check_user():
         if not app.config.get("LOGIN_DISABLED") and request.endpoint:
             # check if the endpoint requires authentication
-            static_endpoint = (
-                "static" in request.endpoint or "report" in request.endpoint
-            )
-            public_endpoint = getattr(
-                app.view_functions[request.endpoint], "is_public", False
-            )
+            static_endpoint = "static" in request.endpoint or request.endpoint == "report.report"
+            public_endpoint = getattr(app.view_functions[request.endpoint], "is_public", False)
             relevant_endpoint = not (static_endpoint or public_endpoint)
             # if endpoint requires auth, check if user is authenticated
             if relevant_endpoint and not current_user.is_authenticated:
@@ -98,7 +94,6 @@ def configure_extensions(app):
     extensions.mongo.init_app(app)
     extensions.store.init_app(app)
     extensions.login_manager.init_app(app)
-    extensions.oauth.init_app(app)
     extensions.mail.init_app(app)
 
     Markdown(app)
@@ -116,6 +111,10 @@ def configure_extensions(app):
         LOG.info("LDAP login enabled")
         # setup connection to server
         extensions.ldap_manager.init_app(app)
+    if app.config.get("GOOGLE"):
+        LOG.info("Google login enabled")
+        # setup connection to google oauth2
+        configure_oauth_login(app)
 
 
 def register_blueprints(app):
@@ -168,6 +167,38 @@ def register_filters(app):
         """Decode a string with encoded hex values."""
         return unquote(string)
 
+    @app.template_filter()
+    def cosmic_prefix(cosmicId):
+        """If cosmicId is an integer, add 'COSM' as prefix
+        otherwise return unchanged"""
+        if isinstance(cosmicId, int):
+            return "COSM" + str(cosmicId)
+        return cosmicId
+
+    @app.template_filter()
+    def fix_punctuation(text):
+        """Adds a white space after puntuation"""
+        return re.sub(r"(?<=[.,:;?!])(?=[^\s])", r" ", text)
+
+
+def configure_oauth_login(app):
+    """Register the Google Oauth login client using config settings"""
+
+    google_conf = app.config["GOOGLE"]
+    discovery_url = google_conf.get("discovery_url")
+    client_id = google_conf.get("client_id")
+    client_secret = google_conf.get("client_secret")
+
+    extensions.oauth_client.init_app(app)
+
+    extensions.oauth_client.register(
+        name="google",
+        server_metadata_url=discovery_url,
+        client_id=client_id,
+        client_secret=client_secret,
+        client_kwargs={"scope": "openid email profile"},
+    )
+
 
 def configure_email_logging(app):
     """Setup logging of error/exceptions to email."""
@@ -184,8 +215,7 @@ def configure_email_logging(app):
     mail_handler.setLevel(logging.ERROR)
     mail_handler.setFormatter(
         logging.Formatter(
-            "%(asctime)s - %(name)s - %(levelname)s: %(message)s "
-            "[in %(pathname)s:%(lineno)d]"
+            "%(asctime)s - %(name)s - %(levelname)s: %(message)s " "[in %(pathname)s:%(lineno)d]"
         )
     )
     app.logger.addHandler(mail_handler)
