@@ -12,7 +12,6 @@ from operator import itemgetter
 import pymongo
 from flask import (
     Blueprint,
-    Response,
     abort,
     current_app,
     flash,
@@ -22,24 +21,19 @@ from flask import (
     request,
     send_file,
     send_from_directory,
+    Response,
     url_for,
 )
+
 from flask_login import current_user
 from flask_weasyprint import HTML, render_pdf
 from werkzeug.datastructures import Headers
 
-from scout.constants import (
-    ACMG_COMPLETE_MAP,
-    ACMG_MAP,
-    CASEDATA_HEADER,
-    CLINVAR_HEADER,
-    SAMPLE_SOURCE,
-)
+from scout.constants import SAMPLE_SOURCE
 from scout.server.extensions import mail, store
 from scout.server.utils import institute_and_case, templated, user_institutes
 
 from . import controllers
-from .forms import GeneVariantFiltersForm
 
 LOG = logging.getLogger(__name__)
 
@@ -65,64 +59,6 @@ def index():
     return dict(institutes=institutes_count)
 
 
-@cases_bp.route("/<institute_id>")
-@templated("cases/cases.html")
-def cases(institute_id):
-    """Display a list of cases for an institute."""
-
-    institute_obj = institute_and_case(store, institute_id)
-    query = request.args.get("query")
-
-    limit = 100
-    if request.args.get("limit"):
-        limit = int(request.args.get("limit"))
-
-    skip_assigned = request.args.get("skip_assigned")
-    is_research = request.args.get("is_research")
-    all_cases = store.cases(
-        collaborator=institute_id,
-        name_query=query,
-        skip_assigned=skip_assigned,
-        is_research=is_research,
-    )
-
-    sort_by = request.args.get("sort")
-    sort_order = request.args.get("order") or "asc"
-    if sort_by:
-        pymongo_sort = pymongo.ASCENDING
-        if sort_order == "desc":
-            pymongo_sort = pymongo.DESCENDING
-        if sort_by == "analysis_date":
-            all_cases.sort("analysis_date", pymongo_sort)
-        elif sort_by == "track":
-            all_cases.sort("track", pymongo_sort)
-        elif sort_by == "status":
-            all_cases.sort("status", pymongo_sort)
-
-    LOG.debug("Prepare all cases")
-
-    prioritized_cases = store.prioritized_cases(institute_id=institute_id)
-
-    data = controllers.cases(store, all_cases, prioritized_cases, limit)
-    data["sort_order"] = sort_order
-    data["sort_by"] = sort_by
-    data["nr_cases"] = store.nr_cases(institute_id=institute_id)
-
-    sanger_unevaluated = controllers.get_sanger_unevaluated(
-        store, institute_id, current_user.email
-    )
-    if len(sanger_unevaluated) > 0:
-        data["sanger_unevaluated"] = sanger_unevaluated
-
-    return dict(
-        institute=institute_obj,
-        skip_assigned=skip_assigned,
-        is_research=is_research,
-        query=query,
-        **data,
-    )
-
-
 @cases_bp.route("/<institute_id>/<case_name>")
 @templated("cases/case.html")
 def case(institute_id, case_name):
@@ -151,115 +87,6 @@ def sma(institute_id, case_name):
     return dict(institute=institute_obj, case=case_obj, format="html", **data)
 
 
-@cases_bp.route("/<institute_id>/clinvar_submissions", methods=["GET", "POST"])
-@templated("cases/clinvar_submissions.html")
-def clinvar_submissions(institute_id):
-    def generate_csv(header, lines):
-        yield header + "\n"
-        for line in lines:  # lines have already quoted fields
-            yield line + "\n"
-
-    if request.method == "POST":
-        submission_id = request.form.get("submission_id")
-        if request.form.get("update_submission"):
-            if request.form.get("update_submission") == "close":  # close a submission
-                store.update_clinvar_submission_status(
-                    institute_id, submission_id, "closed"
-                )
-            elif request.form.get("update_submission") == "open":
-                store.update_clinvar_submission_status(
-                    institute_id, submission_id, "open"
-                )  # open a submission
-            elif request.form.get(
-                "update_submission"
-            ) == "register_id" and request.form.get(
-                "clinvar_id"
-            ):  # provide an official clinvar submission ID
-                result = store.update_clinvar_id(
-                    clinvar_id=request.form.get("clinvar_id"),
-                    submission_id=submission_id,
-                )
-            elif (
-                request.form.get("update_submission") == "delete"
-            ):  # delete a submission
-                deleted_objects, deleted_submissions = store.delete_submission(
-                    submission_id=submission_id
-                )
-                flash(
-                    "Removed {} objects and {} submission from database".format(
-                        deleted_objects, deleted_submissions
-                    ),
-                    "info",
-                )
-        elif request.form.get("delete_variant"):  # delete a variant from a submission
-            store.delete_clinvar_object(
-                object_id=request.form.get("delete_variant"),
-                object_type="variant_data",
-                submission_id=submission_id,
-            )  # remove variant and associated_casedata
-        elif request.form.get("delete_casedata"):  # delete a case from a submission
-            store.delete_clinvar_object(
-                object_id=request.form.get("delete_casedata"),
-                object_type="case_data",
-                submission_id=submission_id,
-            )  # remove just the casedata associated to a variant
-        else:  # Download submission CSV files (for variants or casedata)
-
-            clinvar_subm_id = request.form.get("clinvar_id")
-            if clinvar_subm_id == "":
-                flash(
-                    "In order to download a submission CSV file you should register a Clinvar submission Name first!",
-                    "warning",
-                )
-                return redirect(request.referrer)
-
-            csv_type = request.form.get("csv_type", "")
-
-            submission_objs = store.clinvar_objs(
-                submission_id=submission_id, key_id=csv_type
-            )  # a list of clinvar submission objects (variants or casedata)
-            if submission_objs:
-                csv_header_obj = controllers.clinvar_header(
-                    submission_objs, csv_type
-                )  # custom csv header (dict as in constants CLINVAR_HEADER and CASEDATA_HEADER, but with required fields only)
-                csv_lines = controllers.clinvar_lines(
-                    submission_objs, csv_header_obj
-                )  # csv lines (one for each variant/casedata to be submitted)
-                csv_header = list(csv_header_obj.values())
-                csv_header = [
-                    '"' + str(x) + '"' for x in csv_header
-                ]  # quote columns in header for csv rendering
-                download_day = str(datetime.datetime.now().strftime("%Y-%m-%d"))
-                headers = Headers()
-                headers.add(
-                    "Content-Disposition",
-                    "attachment",
-                    filename=f"{clinvar_subm_id}_{csv_type}_{download_day}.csv",
-                )
-                return Response(
-                    generate_csv(",".join(csv_header), csv_lines),
-                    mimetype="text/csv",
-                    headers=headers,
-                )
-
-            flash(
-                'There are no submission objects of type "{}" to include in the csv file!'.format(
-                    csv_type
-                ),
-                "warning",
-            )
-
-    institute_obj = institute_and_case(store, institute_id)
-
-    data = {
-        "submissions": controllers.clinvar_submissions(store, institute_id),
-        "institute": institute_obj,
-        "variant_header_fields": CLINVAR_HEADER,
-        "casedata_header_fields": CASEDATA_HEADER,
-    }
-    return data
-
-
 @cases_bp.route("/<institute_id>/<case_name>/mme_matches", methods=["GET", "POST"])
 @templated("cases/matchmaker.html")
 def matchmaker_matches(institute_id, case_name):
@@ -295,9 +122,7 @@ def matchmaker_matches(institute_id, case_name):
     return data
 
 
-@cases_bp.route(
-    "/<institute_id>/<case_name>/mme_match/<target>", methods=["GET", "POST"]
-)
+@cases_bp.route("/<institute_id>/<case_name>/mme_match/<target>", methods=["GET", "POST"])
 def matchmaker_match(institute_id, case_name, target):
     """Starts an internal match or a match against one or all MME external nodes"""
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
@@ -329,9 +154,7 @@ def matchmaker_match(institute_id, case_name, target):
         if match_results["status_code"] == 200:
             ok_responses += 1
     if ok_responses:
-        flash(
-            "Match request sent. Look for eventual matches in 'Matches' page.", "info"
-        )
+        flash("Match request sent. Look for eventual matches in 'Matches' page.", "info")
     else:
         flash("An error occurred while sending match request.", "danger")
 
@@ -423,9 +246,7 @@ def matchmaker_add(institute_id, case_name):
             n_succes_response += 1
         else:
             flash(
-                "an error occurred while adding patient to matchmaker: {}".format(
-                    message
-                ),
+                "an error occurred while adding patient to matchmaker: {}".format(message),
                 "warning",
             )
         if message == "Patient was successfully updated.":
@@ -436,9 +257,7 @@ def matchmaker_add(institute_id, case_name):
     # if at least one patient was inserted or updated into matchmaker, save submission at the case level:
     if n_inserted or n_updated:
         category = "success"
-        store.case_mme_update(
-            case_obj=case_obj, user_obj=user_obj, mme_subm_obj=add_result
-        )
+        store.case_mme_update(case_obj=case_obj, user_obj=user_obj, mme_subm_obj=add_result)
     flash(
         "Number of new patients in matchmaker:{0}, number of updated records:{1}, number of failed requests:{2}".format(
             n_inserted,
@@ -497,110 +316,6 @@ def matchmaker_delete(institute_id, case_name):
     return redirect(request.referrer)
 
 
-@cases_bp.route("/<institute_id>/causatives")
-@templated("cases/causatives.html")
-def causatives(institute_id):
-    institute_obj = institute_and_case(store, institute_id)
-    query = request.args.get("query", "")
-    hgnc_id = None
-    if "|" in query:
-        # filter accepts an array of IDs. Provide an array with one ID element
-        try:
-            hgnc_id = [int(query.split(" | ", 1)[0])]
-        except ValueError:
-            flash("Provided gene info could not be parsed!", "warning")
-
-    variants = store.check_causatives(institute_obj=institute_obj, limit_genes=hgnc_id)
-    if variants:
-        variants.sort("hgnc_symbols", pymongo.ASCENDING)
-    all_variants = {}
-    all_cases = {}
-    for variant_obj in variants:
-        if variant_obj["case_id"] not in all_cases:
-            case_obj = store.case(variant_obj["case_id"])
-            all_cases[variant_obj["case_id"]] = case_obj
-        else:
-            case_obj = all_cases[variant_obj["case_id"]]
-
-        if variant_obj["variant_id"] not in all_variants:
-            all_variants[variant_obj["variant_id"]] = []
-
-        all_variants[variant_obj["variant_id"]].append((case_obj, variant_obj))
-
-    acmg_map = {key: ACMG_COMPLETE_MAP[value] for key, value in ACMG_MAP.items()}
-
-    return dict(institute=institute_obj, variant_groups=all_variants, acmg_map=acmg_map)
-
-
-@cases_bp.route("/<institute_id>/gene_variants", methods=["GET", "POST"])
-@templated("cases/gene_variants.html")
-def gene_variants(institute_id):
-    """Display a list of SNV variants."""
-    page = int(request.form.get("page", 1))
-
-    institute_obj = institute_and_case(store, institute_id)
-
-    # populate form, conditional on request method
-    if request.method == "POST":
-        form = GeneVariantFiltersForm(request.form)
-    else:
-        form = GeneVariantFiltersForm(request.args)
-
-    variant_type = form.data.get("variant_type", "clinical")
-
-    # check if supplied gene symbols exist
-    hgnc_symbols = []
-    non_clinical_symbols = []
-    not_found_symbols = []
-    not_found_ids = []
-    data = {}
-    if (form.hgnc_symbols.data) and len(form.hgnc_symbols.data) > 0:
-        is_clinical = form.data.get("variant_type", "clinical") == "clinical"
-        # clinical_symbols = store.clinical_symbols(case_obj) if is_clinical else None
-        for hgnc_symbol in form.hgnc_symbols.data:
-            if hgnc_symbol.isdigit():
-                hgnc_gene = store.hgnc_gene(int(hgnc_symbol))
-                if hgnc_gene is None:
-                    not_found_ids.append(hgnc_symbol)
-                else:
-                    hgnc_symbols.append(hgnc_gene["hgnc_symbol"])
-            elif store.hgnc_genes(hgnc_symbol).count() == 0:
-                not_found_symbols.append(hgnc_symbol)
-            # elif is_clinical and (hgnc_symbol not in clinical_symbols):
-            #     non_clinical_symbols.append(hgnc_symbol)
-            else:
-                hgnc_symbols.append(hgnc_symbol)
-
-        if not_found_ids:
-            flash("HGNC id not found: {}".format(", ".join(not_found_ids)), "warning")
-        if not_found_symbols:
-            flash(
-                "HGNC symbol not found: {}".format(", ".join(not_found_symbols)),
-                "warning",
-            )
-        if non_clinical_symbols:
-            flash(
-                "Gene not included in clinical list: {}".format(
-                    ", ".join(non_clinical_symbols)
-                ),
-                "warning",
-            )
-        form.hgnc_symbols.data = hgnc_symbols
-
-        LOG.debug("query {}".format(form.data))
-
-        variants_query = store.gene_variants(
-            query=form.data,
-            institute_id=institute_id,
-            category="snv",
-            variant_type=variant_type,
-        )
-
-        data = controllers.gene_variants(store, variants_query, institute_id, page)
-
-    return dict(institute=institute_obj, form=form, page=page, **data)
-
-
 @cases_bp.route("/<institute_id>/<case_name>/individuals", methods=["POST"])
 def update_individual(institute_id, case_name):
     """Update individual data (age and/or Tissue type) for a case"""
@@ -681,9 +396,7 @@ def pdf_case_report(institute_id, case_name):
 
     # workaround to be able to print the case pedigree to pdf
     if case_obj.get("madeline_info") is not None:
-        with open(
-            os.path.join(cases_bp.static_folder, "madeline.svg"), "w"
-        ) as temp_madeline:
+        with open(os.path.join(cases_bp.static_folder, "madeline.svg"), "w") as temp_madeline:
             temp_madeline.write(case_obj["madeline_info"])
 
     html_report = render_template(
@@ -707,9 +420,7 @@ def mt_report(institute_id, case_name):
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
 
     # create a temp folder to write excel files into
-    temp_excel_dir = os.path.join(
-        cases_bp.static_folder, "_".join([case_name, "mt_reports"])
-    )
+    temp_excel_dir = os.path.join(cases_bp.static_folder, "_".join([case_name, "mt_reports"]))
     os.makedirs(temp_excel_dir, exist_ok=True)
 
     # create mt excel files, one for each sample
@@ -731,8 +442,7 @@ def mt_report(institute_id, case_name):
             data,
             mimetype="application/zip",
             as_attachment=True,
-            attachment_filename="_".join(["scout", case_name, "MT_report", today])
-            + ".zip",
+            attachment_filename="_".join(["scout", case_name, "MT_report", today]) + ".zip",
             cache_timeout=0,
         )
 
@@ -773,9 +483,7 @@ def case_diagnosis(institute_id, case_name):
 
 
 @cases_bp.route("/<institute_id>/<case_name>/phenotypes", methods=["POST"])
-@cases_bp.route(
-    "/<institute_id>/<case_name>/phenotypes/<phenotype_id>", methods=["POST"]
-)
+@cases_bp.route("/<institute_id>/<case_name>/phenotypes/<phenotype_id>", methods=["POST"])
 def phenotypes(institute_id, case_name, phenotype_id=None):
     """Handle phenotypes."""
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
@@ -817,13 +525,13 @@ def phenotypes(institute_id, case_name, phenotype_id=None):
 
 
 def parse_raw_gene_ids(raw_symbols):
-    """ Parse raw gene symbols for hgnc_symbols from web form autocompletion.
+    """Parse raw gene symbols for hgnc_symbols from web form autocompletion.
 
-        Arguments:
-            raw_symbol_strings(list(string)) - formated "17284 | POT1 (hPot1, POT1)"
+    Arguments:
+        raw_symbol_strings(list(string)) - formated "17284 | POT1 (hPot1, POT1)"
 
-        Returns:
-            hgnc_ids(set(int))
+    Returns:
+        hgnc_ids(set(int))
     """
     hgnc_ids = set()
 
@@ -847,13 +555,13 @@ def parse_raw_gene_ids(raw_symbols):
 
 
 def parse_raw_gene_symbols(raw_symbols_list):
-    """ Parse list of concatenated gene symbol list for hgnc_symbols from Phenomizer.
+    """Parse list of concatenated gene symbol list for hgnc_symbols from Phenomizer.
 
-        Arguments:
-            raw_symbols(list(string)) - e.g. ("POT1 | MUTYH", "POT1 | ATXN1 | ATXN7")
+    Arguments:
+        raw_symbols(list(string)) - e.g. ("POT1 | MUTYH", "POT1 | ATXN1 | ATXN7")
 
-        Returns:
-            hgnc_symbols(set(string)) - set of (unique) gene symbols without intervening chars
+    Returns:
+        hgnc_symbols(set(string)) - set of (unique) gene symbols without intervening chars
     """
     hgnc_symbols = set()
 
@@ -880,9 +588,7 @@ def phenotypes_actions(institute_id, case_name):
 
     if action == "PHENOMIZER":
         if len(hpo_ids) == 0:
-            hpo_ids = [
-                term["phenotype_id"] for term in case_obj.get("phenotype_terms", [])
-            ]
+            hpo_ids = [term["phenotype_id"] for term in case_obj.get("phenotype_terms", [])]
 
         username = current_app.config["PHENOMIZER_USERNAME"]
         password = current_app.config["PHENOMIZER_PASSWORD"]
@@ -909,16 +615,12 @@ def phenotypes_actions(institute_id, case_name):
 
     if action == "GENERATE":
         if len(hpo_ids) == 0:
-            hpo_ids = [
-                term["phenotype_id"] for term in case_obj.get("phenotype_terms", [])
-            ]
+            hpo_ids = [term["phenotype_id"] for term in case_obj.get("phenotype_terms", [])]
         results = store.generate_hpo_gene_list(*hpo_ids)
         # determine how many HPO terms each gene must match
         hpo_count = int(request.form.get("min_match") or 1)
         hgnc_ids = [result[0] for result in results if result[1] >= hpo_count]
-        store.update_dynamic_gene_list(
-            case_obj, hgnc_ids=hgnc_ids, phenotype_ids=hpo_ids
-        )
+        store.update_dynamic_gene_list(case_obj, hgnc_ids=hgnc_ids, phenotype_ids=hpo_ids)
 
     return redirect(case_url)
 
@@ -975,9 +677,7 @@ def status(institute_id, case_name):
 
 
 @cases_bp.route("/<institute_id>/<case_name>/assign", methods=["POST"])
-@cases_bp.route(
-    "/<institute_id>/<case_name>/<user_id>/<inactivate>/assign", methods=["POST"]
-)
+@cases_bp.route("/<institute_id>/<case_name>/<user_id>/<inactivate>/assign", methods=["POST"])
 def assign(institute_id, case_name, user_id=None, inactivate=False):
     """Assign and unassign a user from a case."""
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
@@ -1088,22 +788,20 @@ def mark_causative(institute_id, case_name, variant_id, partial_causative=False)
         else:
             store.mark_causative(institute_obj, case_obj, user_obj, link, variant_obj)
     elif request.form["action"] == "DELETE":
-        if partial_causative:
-            store.unmark_partial_causative(
-                institute_obj, case_obj, user_obj, link, variant_obj
-            )
+        if partial_causative == "True":
+            store.unmark_partial_causative(institute_obj, case_obj, user_obj, link, variant_obj)
         else:
             store.unmark_causative(institute_obj, case_obj, user_obj, link, variant_obj)
 
     # send the user back to the case that was marked as solved
     case_url = url_for(".case", institute_id=institute_id, case_name=case_name)
-    return redirect(case_url)
+    return redirect(request.referrer)
 
 
 @cases_bp.route("/<institute_id>/<case_name>/check-case", methods=["POST"])
 def check_case(institute_id, case_name):
     """Mark a case that is has been checked.
-       This means to set case['needs_check'] to False
+    This means to set case['needs_check'] to False
     """
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     store.case_collection.find_one_and_update(
@@ -1169,10 +867,13 @@ def share(institute_id, case_name):
     revoke_access = "revoke" in request.form
     link = url_for(".case", institute_id=institute_id, case_name=case_name)
 
-    if revoke_access:
-        store.unshare(institute_obj, case_obj, collaborator_id, user_obj, link)
-    else:
-        store.share(institute_obj, case_obj, collaborator_id, user_obj, link)
+    try:
+        if revoke_access:
+            store.unshare(institute_obj, case_obj, collaborator_id, user_obj, link)
+        else:
+            store.share(institute_obj, case_obj, collaborator_id, user_obj, link)
+    except ValueError as ex:
+        flash(str(ex), "warning")
 
     return redirect(request.referrer)
 
@@ -1183,9 +884,7 @@ def rerun(institute_id, case_name):
     sender = current_app.config.get("MAIL_USERNAME")
     recipient = current_app.config.get("TICKET_SYSTEM_EMAIL")
 
-    controllers.rerun(
-        store, mail, current_user, institute_id, case_name, sender, recipient
-    )
+    controllers.rerun(store, mail, current_user, institute_id, case_name, sender, recipient)
     return redirect(request.referrer)
 
 
@@ -1217,15 +916,11 @@ def cohorts(institute_id, case_name):
 def default_panels(institute_id, case_name):
     """Update default panels for a case."""
     panel_ids = request.form.getlist("panel_ids")
-    controllers.update_default_panels(
-        store, current_user, institute_id, case_name, panel_ids
-    )
+    controllers.update_default_panels(store, current_user, institute_id, case_name, panel_ids)
     return redirect(request.referrer)
 
 
-@cases_bp.route(
-    "/<institute_id>/<case_name>/update-clinical-filter-hpo", methods=["POST"]
-)
+@cases_bp.route("/<institute_id>/<case_name>/update-clinical-filter-hpo", methods=["POST"])
 def update_clinical_filter_hpo(institute_id, case_name):
     """Update default panels for a case."""
     hpo_clinical_filter = request.form.get("hpo_clinical_filter")
@@ -1235,6 +930,40 @@ def update_clinical_filter_hpo(institute_id, case_name):
     return redirect(request.referrer)
 
 
+@cases_bp.route("/<institute_id>/<case_name>/download-hpo-genes", methods=["GET"])
+def download_hpo_genes(institute_id, case_name):
+    """Download the genes contained in a case dynamic gene list"""
+
+    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    dynamic_gene_objs = case_obj.get("dynamic_gene_list")
+    csv_header = ["HGNC symbol", "HGNC ID", "Description"]
+    csv_lines = [
+        ",".join(
+            [
+                str(gene_obj.get("hgnc_symbol")),
+                str(gene_obj.get("hgnc_id")),
+                '"' + gene_obj.get("description") + '"',
+            ]
+        )
+        for gene_obj in dynamic_gene_objs
+    ]
+
+    download_day = str(datetime.datetime.now().strftime("%Y-%m-%d"))
+    # prepare headers:
+    headers = Headers()
+
+    headers.add(
+        "Content-Disposition",
+        "attachment",
+        filename=f"HPO_gene_list.{institute_id}.{case_name}.{download_day}.csv",
+    )
+    return Response(
+        _generate_csv(",".join(csv_header), csv_lines),
+        mimetype="text/csv",
+        headers=headers,
+    )
+
+
 @cases_bp.route("/<institute_id>/<case_name>/<individual_id>/cgh")
 def vcf2cytosure(institute_id, case_name, individual_id):
     """Download vcf2cytosure file for individual."""
@@ -1242,14 +971,13 @@ def vcf2cytosure(institute_id, case_name, individual_id):
     (display_name, vcf2cytosure) = controllers.vcf2cytosure(
         store, institute_id, case_name, individual_id
     )
-
+    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     outdir = os.path.abspath(os.path.dirname(vcf2cytosure))
     filename = os.path.basename(vcf2cytosure)
-
-    LOG.debug("Attempt to deliver file {0} from dir {1}".format(filename, outdir))
-
-    attachment_filename = display_name + ".vcf2cytosure.cgh"
-
+    attachment_filename = ".".join(
+        [display_name, case_obj["display_name"], case_obj["_id"], "vcf2cytosure.cgh"]
+    )
+    LOG.debug("Attempt to deliver file {0} from dir {1}".format(attachment_filename, outdir))
     return send_from_directory(
         outdir, filename, attachment_filename=attachment_filename, as_attachment=True
     )
@@ -1292,3 +1020,10 @@ def host_image_aux(institute_id, case_name, image, imgstr):
     img_path = abs_path + "/" + imgstr
     LOG.debug("Attempting to send {}/{}".format(img_path, image))
     return send_from_directory(img_path, image)
+
+
+def _generate_csv(header, lines):
+    """Download a text file composed of any header and lines"""
+    yield header + "\n"
+    for line in lines:  # lines have already quoted fields
+        yield line + "\n"
