@@ -16,11 +16,18 @@ from flask import (
     redirect,
     request,
     send_file,
+    session,
     url_for,
 )
 from flask_login import current_user
 
-from scout.constants import CANCER_TIER_OPTIONS, MANUAL_RANK_OPTIONS, SEVERE_SO_TERMS
+from scout.constants import (
+    CANCER_TIER_OPTIONS,
+    MANUAL_RANK_OPTIONS,
+    SEVERE_SO_TERMS,
+    DISMISS_VARIANT_OPTIONS,
+    CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
+)
 from scout.server.extensions import store
 from scout.server.utils import institute_and_case, templated
 
@@ -28,8 +35,13 @@ from . import controllers
 from .forms import CancerFiltersForm, FiltersForm, StrFiltersForm, SvFiltersForm
 
 LOG = logging.getLogger(__name__)
+
 variants_bp = Blueprint(
-    "variants", __name__, static_folder="static", template_folder="templates"
+    "variants",
+    __name__,
+    template_folder="templates",
+    static_folder="static",
+    static_url_path="/variants/static",
 )
 
 
@@ -38,7 +50,6 @@ variants_bp = Blueprint(
 def variants(institute_id, case_name):
     """Display a list of SNV variants."""
     page = int(request.form.get("page", 1))
-
     category = "snv"
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     variant_type = request.args.get("variant_type", "clinical")
@@ -49,7 +60,16 @@ def variants(institute_id, case_name):
     user_obj = store.user(current_user.email)
 
     if request.method == "POST":
-        # If special filter buttons were selected:
+        if request.form.getlist("dismiss"):  # dismiss a list of variants
+            controllers.dismiss_variant_list(
+                store,
+                institute_obj,
+                case_obj,
+                "variant.variant",
+                request.form.getlist("dismiss"),
+                request.form.getlist("dismiss_choices"),
+            )
+
         form = controllers.populate_filters_form(
             store, institute_obj, case_obj, user_obj, category, request.form
         )
@@ -57,6 +77,15 @@ def variants(institute_id, case_name):
         form = FiltersForm(request.args)
         # set form variant data type the first time around
         form.variant_type.data = variant_type
+        # set chromosome to all chromosomes
+        form.chrom.data = request.args.get("chrom", "")
+
+        if form.gene_panels.data == []:
+            form.gene_panels.data = [
+                panel["panel_name"]
+                for panel in case_obj.get("panels", [])
+                if panel["is_default"] is True
+            ]
 
     # populate filters dropdown
     available_filters = store.filters(institute_id, category)
@@ -65,15 +94,7 @@ def variants(institute_id, case_name):
     ]
 
     # populate available panel choices
-    available_panels = case_obj.get("panels", []) + [
-        {"panel_name": "hpo", "display_name": "HPO"}
-    ]
-
-    panel_choices = [
-        (panel["panel_name"], panel["display_name"]) for panel in available_panels
-    ]
-
-    form.gene_panels.choices = panel_choices
+    form.gene_panels.choices = controllers.gene_panel_choices(institute_obj, case_obj)
 
     # update status of case if visited for the first time
     controllers.activate_case(store, institute_obj, case_obj, current_user)
@@ -92,9 +113,7 @@ def variants(institute_id, case_name):
 
         hgnc_symbols_set = set(form.hgnc_symbols.data)
         LOG.debug("Symbols prior to upload: {0}".format(hgnc_symbols_set))
-        new_hgnc_symbols = controllers.upload_panel(
-            store, institute_id, case_name, stream
-        )
+        new_hgnc_symbols = controllers.upload_panel(store, institute_id, case_name, stream)
         hgnc_symbols_set.update(new_hgnc_symbols)
         form.hgnc_symbols.data = hgnc_symbols_set
         # reset gene panels
@@ -125,14 +144,10 @@ def variants(institute_id, case_name):
     if not_found_ids:
         flash("HGNC id not found: {}".format(", ".join(not_found_ids)), "warning")
     if not_found_symbols:
-        flash(
-            "HGNC symbol not found: {}".format(", ".join(not_found_symbols)), "warning"
-        )
+        flash("HGNC symbol not found: {}".format(", ".join(not_found_symbols)), "warning")
     if non_clinical_symbols:
         flash(
-            "Gene not included in clinical list: {}".format(
-                ", ".join(non_clinical_symbols)
-            ),
+            "Gene not included in clinical list: {}".format(", ".join(non_clinical_symbols)),
             "warning",
         )
     form.hgnc_symbols.data = hgnc_symbols
@@ -147,8 +162,14 @@ def variants(institute_id, case_name):
         current_symbols.update(hpo_symbols)
         form.hgnc_symbols.data = list(current_symbols)
 
+    cytobands = store.cytoband_by_chrom(case_obj.get("genome_build"))
+
     variants_query = store.variants(case_obj["_id"], query=form.data, category=category)
 
+    # Setup variant count session with variant count by category
+    controllers.variant_count_session(store, institute_id, case_obj["_id"], variant_type, category)
+    session["filtered_variants"] = variants_query.count()
+
     if request.form.get("export"):
         return controllers.download_variants(store, case_obj, variants_query)
 
@@ -158,10 +179,13 @@ def variants(institute_id, case_name):
         case=case_obj,
         form=form,
         manual_rank_options=MANUAL_RANK_OPTIONS,
+        dismiss_variant_options=DISMISS_VARIANT_OPTIONS,
         cancer_tier_options=CANCER_TIER_OPTIONS,
         severe_so_terms=SEVERE_SO_TERMS,
+        cytobands=cytobands,
         page=page,
-        **data
+        expand_search=str(request.method == "POST"),
+        **data,
     )
 
 
@@ -182,26 +206,24 @@ def str_variants(institute_id, case_name):
     query = form.data
     query["variant_type"] = variant_type
 
-    variants_query = store.variants(
-        case_obj["_id"], category=category, query=query
-    ).sort(
+    variants_query = store.variants(case_obj["_id"], category=category, query=query).sort(
         [
             ("str_repid", pymongo.ASCENDING),
             ("chromosome", pymongo.ASCENDING),
             ("position", pymongo.ASCENDING),
         ]
     )
-    data = controllers.str_variants(
-        store, institute_obj, case_obj, variants_query, page
-    )
+
+    data = controllers.str_variants(store, institute_obj, case_obj, variants_query, page)
     return dict(
         institute=institute_obj,
         case=case_obj,
+        dismiss_variant_options=DISMISS_VARIANT_OPTIONS,
         variant_type=variant_type,
         manual_rank_options=MANUAL_RANK_OPTIONS,
         form=form,
         page=page,
-        **data
+        **data,
     )
 
 
@@ -219,14 +241,27 @@ def sv_variants(institute_id, case_name):
     if request.form.get("hpo_clinical_filter"):
         case_obj["hpo_clinical_filter"] = True
 
+    if request.form.getlist("dismiss"):  # dismiss a list of variants
+        controllers.dismiss_variant_list(
+            store,
+            institute_obj,
+            case_obj,
+            "variant.sv_variant",
+            request.form.getlist("dismiss"),
+            request.form.getlist("dismiss_choices"),
+        )
+
     # update status of case if visited for the first time
     controllers.activate_case(store, institute_obj, case_obj, current_user)
-
-    form = controllers.populate_sv_filters_form(
-        store, institute_obj, case_obj, category, request
-    )
+    form = controllers.populate_sv_filters_form(store, institute_obj, case_obj, category, request)
+    cytobands = store.cytoband_by_chrom(case_obj.get("genome_build"))
 
     variants_query = store.variants(case_obj["_id"], category=category, query=form.data)
+
+    # Setup variant count session with variant count by category
+    controllers.variant_count_session(store, institute_id, case_obj["_id"], variant_type, category)
+    session["filtered_variants"] = variants_query.count()
+
     # if variants should be exported
     if request.form.get("export"):
         return controllers.download_variants(store, case_obj, variants_query)
@@ -236,18 +271,19 @@ def sv_variants(institute_id, case_name):
     return dict(
         institute=institute_obj,
         case=case_obj,
+        dismiss_variant_options=DISMISS_VARIANT_OPTIONS,
         variant_type=variant_type,
         form=form,
+        cytobands=cytobands,
         severe_so_terms=SEVERE_SO_TERMS,
         manual_rank_options=MANUAL_RANK_OPTIONS,
         page=page,
-        **data
+        expand_search=str(request.method == "POST"),
+        **data,
     )
 
 
-@variants_bp.route(
-    "/<institute_id>/<case_name>/cancer/variants", methods=["GET", "POST"]
-)
+@variants_bp.route("/<institute_id>/<case_name>/cancer/variants", methods=["GET", "POST"])
 @templated("variants/cancer-variants.html")
 def cancer_variants(institute_id, case_name):
     """Show cancer variants overview."""
@@ -257,13 +293,48 @@ def cancer_variants(institute_id, case_name):
 
     user_obj = store.user(current_user.email)
     if request.method == "POST":
-        page = int(request.form.get("page", 1))
+        if request.form.getlist("dismiss"):  # dismiss a list of variants
+            controllers.dismiss_variant_list(
+                store,
+                institute_obj,
+                case_obj,
+                "variant.variant",
+                request.form.getlist("dismiss"),
+                request.form.getlist("dismiss_choices"),
+            )
+
         form = controllers.populate_filters_form(
             store, institute_obj, case_obj, user_obj, category, request.form
         )
+
+        # if user is not loading an existing filter, check filter form
+        if request.form.get("load_filter") is None and form.validate_on_submit() is False:
+            # Flash a message with errors
+            for field, err_list in form.errors.items():
+                for err in err_list:
+                    flash(f"Content of field '{field}' has not a valid format", "warning")
+            # And do not submit the form
+            return redirect(
+                url_for(
+                    ".cancer_variants",
+                    institute_id=institute_id,
+                    case_name=case_name,
+                    expand_search="True",
+                ),
+            )
+        page = int(request.form.get("page", 1))
+
     else:
         page = int(request.args.get("page", 1))
         form = CancerFiltersForm(request.args)
+        # set chromosome to all chromosomes
+        form.chrom.data = request.args.get("chrom", "")
+        if form.gene_panels.data == []:
+            form.gene_panels.data = [
+                panel["panel_name"]
+                for panel in case_obj.get("panels", [])
+                if panel["is_default"] is True
+            ]
 
     # update status of case if visited for the first time
     controllers.activate_case(store, institute_obj, case_obj, current_user)
@@ -274,23 +345,33 @@ def cancer_variants(institute_id, case_name):
         (filter.get("_id"), filter.get("display_name")) for filter in available_filters
     ]
 
-    available_panels = case_obj.get("panels", []) + [
-        {"panel_name": "hpo", "display_name": "HPO"}
-    ]
+    form.gene_panels.choices = controllers.gene_panel_choices(institute_obj, case_obj)
 
-    panel_choices = [
-        (panel["panel_name"], panel["display_name"]) for panel in available_panels
-    ]
-    form.gene_panels.choices = panel_choices
+    cytobands = store.cytoband_by_chrom(case_obj.get("genome_build"))
 
     variant_type = request.args.get("variant_type", "clinical")
-    data = controllers.cancer_variants(store, institute_id, case_name, form, page=page)
-    return dict(variant_type=variant_type, **data)
+    variants_query = store.variants(case_obj["_id"], category="cancer", query=form.data)
+
+    if request.form.get("export"):
+        return controllers.download_variants(store, case_obj, variants_query)
+
+    data = controllers.cancer_variants(
+        store, institute_id, case_name, variants_query, form, page=page
+    )
+
+    return dict(
+        variant_type=variant_type,
+        cytobands=cytobands,
+        dismiss_variant_options={
+            **DISMISS_VARIANT_OPTIONS,
+            **CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
+        },
+        expand_search=str(request.method == "POST"),
+        **data,
+    )
 
 
-@variants_bp.route(
-    "/<institute_id>/<case_name>/cancer/sv-variants", methods=["GET", "POST"]
-)
+@variants_bp.route("/<institute_id>/<case_name>/cancer/sv-variants", methods=["GET", "POST"])
 @templated("variants/cancer-sv-variants.html")
 def cancer_sv_variants(institute_id, case_name):
     """Display a list of cancer structural variants."""
@@ -307,11 +388,16 @@ def cancer_sv_variants(institute_id, case_name):
     # update status of case if visited for the first time
     controllers.activate_case(store, institute_obj, case_obj, current_user)
 
-    form = controllers.populate_sv_filters_form(
-        store, institute_obj, case_obj, category, request
-    )
+    form = controllers.populate_sv_filters_form(store, institute_obj, case_obj, category, request)
+
+    cytobands = store.cytoband_by_chrom(case_obj.get("genome_build"))
 
     variants_query = store.variants(case_obj["_id"], category=category, query=form.data)
+
+    # Setup variant count session with variant count by category
+    controllers.variant_count_session(store, institute_id, case_obj["_id"], variant_type, category)
+    session["filtered_variants"] = variants_query.count()
+
     # if variants should be exported
     if request.form.get("export"):
         return controllers.download_variants(store, case_obj, variants_query)
@@ -321,13 +407,19 @@ def cancer_sv_variants(institute_id, case_name):
     return dict(
         institute=institute_obj,
         case=case_obj,
+        dismiss_variant_options={
+            **DISMISS_VARIANT_OPTIONS,
+            **CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
+        },
         variant_type=variant_type,
         form=form,
         severe_so_terms=SEVERE_SO_TERMS,
         cancer_tier_options=CANCER_TIER_OPTIONS,
         manual_rank_options=MANUAL_RANK_OPTIONS,
+        cytobands=cytobands,
         page=page,
-        **data
+        expand_search=str(request.method == "POST"),
+        **data,
     )
 
 
@@ -366,14 +458,12 @@ def upload_panel(institute_id, case_name):
                 ".sv_variants",
                 institute_id=institute_id,
                 case_name=case_name,
-                **form.data
+                **form.data,
             ),
             code=307,
         )
     return redirect(
-        url_for(
-            ".variants", institute_id=institute_id, case_name=case_name, **form.data
-        ),
+        url_for(".variants", institute_id=institute_id, case_name=case_name, **form.data),
         code=307,
     )
 
@@ -386,9 +476,7 @@ def download_verified():
     temp_excel_dir = os.path.join(variants_bp.static_folder, "verified_folder")
     os.makedirs(temp_excel_dir, exist_ok=True)
 
-    written_files = controllers.verified_excel_file(
-        store, user_institutes, temp_excel_dir
-    )
+    written_files = controllers.verified_excel_file(store, user_institutes, temp_excel_dir)
     if written_files:
         today = datetime.datetime.now().strftime("%Y-%m-%d")
         # zip the files on the fly and serve the archive to the user
@@ -405,8 +493,7 @@ def download_verified():
             data,
             mimetype="application/zip",
             as_attachment=True,
-            attachment_filename="_".join(["scout", "verified_variants", today])
-            + ".zip",
+            attachment_filename="_".join(["scout", "verified_variants", today]) + ".zip",
             cache_timeout=0,
         )
     flash("No verified variants could be exported for user's institutes", "warning")
